summaryrefslogtreecommitdiff
path: root/src/script/api/script_townlist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_townlist.cpp')
-rw-r--r--src/script/api/script_townlist.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/script/api/script_townlist.cpp b/src/script/api/script_townlist.cpp
index 749555722..33a3fc070 100644
--- a/src/script/api/script_townlist.cpp
+++ b/src/script/api/script_townlist.cpp
@@ -7,13 +7,13 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file script_townlist.cpp Implementation of AITownList and friends. */
#include "../../stdafx.h"
#include "script_townlist.hpp"
#include "../../town.h"
-AITownList::AITownList()
+ScriptTownList::ScriptTownList()
{
Town *t;
FOR_ALL_TOWNS(t) {
@@ -21,7 +21,7 @@ AITownList::AITownList()
}
}
-AITownEffectList::AITownEffectList()
+ScriptTownEffectList::ScriptTownEffectList()
{
for (int i = TE_BEGIN; i < TE_END; i++) {
this->AddItem(i);
@@ -7,13 +7,13 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file script_townlist.cpp Implementation of AITownList and friends. */
+/** @file script_townlist.cpp Implementation of ScriptTownList and friends. */
#include "../../stdafx.h"
#include "script_townlist.hpp"